pub struct MonitorOptions {
pub chain: Chain,
pub task_run_wait_msecs: u64,
pub abandoned_msecs: u64,
pub msecs_wait_per_merkle_proof_service_req: u64,
pub unproven_attempts_limit_test: u32,
pub unproven_attempts_limit_main: u32,
pub callback_token: Option<String>,
pub on_tx_broadcasted: Option<AsyncCallback<String>>,
pub on_tx_proven: Option<AsyncCallback<String>>,
pub on_tx_status_changed: Option<AsyncCallback<(String, String)>>,
}Expand description
Configuration options for the Monitor.
Matches the TS MonitorOptions interface from Monitor.ts.
Fields
chain: ChainWhich chain this monitor operates on.
task_run_wait_msecs: u64How many msecs to wait after each task run iteration.
abandoned_msecs: u64How many msecs before a transaction is considered abandoned.
msecs_wait_per_merkle_proof_service_req: u64How many msecs to wait between merkle proof service requests.
unproven_attempts_limit_test: u32Max unproven attempts before giving up (testnet).
unproven_attempts_limit_main: u32Max unproven attempts before giving up (mainnet).
callback_token: Option<String>Stable callback token for ARC SSE event streaming.
on_tx_broadcasted: Option<AsyncCallback<String>>Hook called when a transaction is broadcasted.
on_tx_proven: Option<AsyncCallback<String>>Hook called when a transaction is proven.
on_tx_status_changed: Option<AsyncCallback<(String, String)>>Hook called when a transaction status changes.