pub struct BlockHeader {
pub version: u32,
pub previous_hash: String,
pub merkle_root: String,
pub time: u32,
pub bits: u32,
pub nonce: u32,
pub height: u32,
pub hash: String,
}Expand description
Fields of an 80-byte serialized block header whose double SHA-256 hash produces the block hash.
All hash values are 32-byte hex strings with byte order reversed from the serialized byte order.
Fields
version: u32Block header version value (4 bytes serialized).
previous_hash: StringHash of the previous block header (32 bytes serialized).
merkle_root: StringRoot hash of the merkle tree of all transactions (32 bytes serialized).
time: u32Block header time value (4 bytes serialized).
bits: u32Block header bits (difficulty target) value (4 bytes serialized).
nonce: u32Block header nonce value (4 bytes serialized).
height: u32Height of the header, starting from zero.
hash: StringThe double SHA-256 hash of the serialized base header fields.