pub struct TaskReorg { /* private fields */ }Expand description
Background task that handles chain reorg processing.
Processes deactivated block headers by finding ProvenTx records that reference those blocks and attempting to get updated merkle proofs. Uses an aging pattern to delay processing, allowing the chain to stabilize.
Implementations
Sourceimpl TaskReorg
impl TaskReorg
Sourcepub fn new(
storage: WalletStorageManager,
services: Arc<dyn WalletServices>,
deactivated_headers: Arc<Mutex<Vec<DeactivatedHeader>>>,
) -> Self
pub fn new( storage: WalletStorageManager, services: Arc<dyn WalletServices>, deactivated_headers: Arc<Mutex<Vec<DeactivatedHeader>>>, ) -> Self
Create a new TaskReorg with default intervals.
Sourcepub fn with_intervals(
storage: WalletStorageManager,
services: Arc<dyn WalletServices>,
deactivated_headers: Arc<Mutex<Vec<DeactivatedHeader>>>,
aged_msecs: u64,
max_retries: u32,
trigger_msecs: u64,
) -> Self
pub fn with_intervals( storage: WalletStorageManager, services: Arc<dyn WalletServices>, deactivated_headers: Arc<Mutex<Vec<DeactivatedHeader>>>, aged_msecs: u64, max_retries: u32, trigger_msecs: u64, ) -> Self
Create with custom intervals.